Impressum — mosaik 2.2.0 documentation

# Impressum

Anschrift

OFFIS e. V.
Escherweg 2
26121 Oldenburg
Telefon +49 441 9722-0
Fax +49 441 9722-102
E-Mail: institut [ A T ] offis.de
Internet: www.offis.de

Vertretungsberechtigter Vorstand

Prof. Dr.-Ing. Wolfgang H. Nebel (Vorsitzender)
Prof. Dr. Dr. h.c. Hans-Jürgen Appelrath
Prof. Dr. techn. Susanne Boll-Westermann
Prof. Dr. Werner Damm
Prof. Dr.-Ing. Andreas Hein

Registergericht

Amtsgericht Oldenburg
Registernummer VR 1956

Umsatzsteuer-Identifikationsnummer (USt-IdNr.)

DE 811582102

Inhaltlich Verantwortlicher gemäß § 55 RStV

Dr. Christoph Mayer (Bereichsleiter)
OFFIS e.V.
Escherweg 2
26121 Oldenburg

Haftungshinweis

Trotz sorgfältiger inhaltlicher Kontrolle übernehmen wir keine Haftung für die Inhalte externer Links. Für den Inhalt der verlinkten Seiten sind ausschließlich deren Betreiber verantwortlich. Die verlinkten Seiten wurden zum Zeitpunkt der Verlinkung auf mögliche Rechtsverstöße überprüft. Rechtswidrige Inhalte waren zum Zeitpunkt der Verlinkung nicht erkennbar. Eine permanente inhaltliche Kontrolle der verlinkten Seiten ist jedoch ohne konkrete Anhaltspunkte einer Rechtsverletzung nicht zumutbar. Bei Bekanntwerden von Rechtsverletzungen werden wir derartige Links umgehend entfernen.

Datenschutz

Mehr zum Thema Datenschutz finden Sie hier.